/* guess_file_type.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "guess_file_type.h"
#include "get_basename.h"
#include "queryResult.h"
#include "database.h"
#include "dataCell.h"

int
guess_file_type(const string &filename) {
  // Look up the filename extension in the soundfile_exts table to get
  // the file type.

  // A file may have multiple extensions.  For instance, file.wav.gz
  // has the extension .gz as well as .wav.gz.  We'll look up all of
  // them, starting with the longest string.  For this reason, we
  // can't use get_filename_extension().

  // However, we can use get_basename().
  string basename = get_basename(filename);

  int dot = basename.find('.');
  while (dot != string::npos) {
    string extension = basename.substr(dot);
    QueryResult qr = music_db->sql_command
      ("SELECT soundfile_id FROM soundfile_exts"
       " WHERE extension=" + DataCell(extension));
    if (qr.get_num_rows() > 0) {
      return qr.get_cell(0, 0).get_int();
    }

    dot = basename.find('.', dot+1);
  }

  // Nope, no match.  Too bad.
  return -1;
}
